@@ -6,7 +6,8 @@ from names_matcher.algorithm import NamesMatcher
 def test_docstring():
     assignments = NamesMatcher()([["Vadim Markovtsev", "vmarkovtsev"], ["Long, Waren", "warenlg"]],
                                  [["Warren"], ["VMarkovtsev"], "Eiso Kant"])
-    assert assignments.tolist() == [1, 0]
+    assert assignments[0].tolist() == [1, 0]
+    assert assignments[1].tolist() == [0.75, 0.5714285714285714]
 
 
 @pytest.mark.parametrize("names, result", [
@@ -29,3 +30,8 @@ def test_reap_idenity(names, result):
 ])
 def test_distance(names1, names2, result):
     assert NamesMatcher.distance(names1, names2) == pytest.approx(result)
+
+
+def test_warning():
+    with pytest.warns(ResourceWarning):
+        NamesMatcher().match_parts(*([[{str(i)} for i in range(5001)]] * 2))
